Learn R Programming

bossR (version 1.0.4)

myGene: clinical dataset

Description

This data set gives the expression levels of gene data, overall survival time, and censoring status from 500 lung adenocarcinoma cases.

Usage

myGene

Arguments

Format

A dataframe containing 500 observations of 3 variables.

References

Xuanjin Cheng, Yongxing Liu, Jiahe Wang, Yujie Chen, Andrew Gordon Robertson, Xuekui Zhang, Steven J M Jones, and Stefan Taubert. (2022) cSurvival: a web resource for biomarker interactions in cancer outcomes and in cell lines. Briefings in Bioinformatics.